==> NetworkManager-1.21.2.tar.xz: NetworkManager-1.21.2/libnm/nm-device-wpan.c <==
// SPDX-License-Identifier: LGPL-2.1+
/*
 * Copyright 2018 Lubomir Rintel <lkundrak@v3.sk>
 */

#include "nm-default.h"

#include "nm-device-wpan.h"

#include "nm-object-private.h"
#include "nm-setting-wpan.h"
#include "nm-setting-connection.h"

enum {
        PROP_0,
        PROP_HW_ADDRESS,

        LAST_PROP
};

typedef struct {
        char *hw_address;
} NMDeviceWpanPrivate;

/**
 * NMDeviceWpan:
 */
struct _NMDeviceWpan {
        NMDevice parent;
};

typedef struct {
        NMDeviceClass parent;
} NMDeviceWpanClass;

G_DEFINE_TYPE (NMDeviceWpan, nm_device_wpan, NM_TYPE_DEVICE)

#define NM_DEVICE_WPAN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), NM_TYPE_DEVICE_WPAN, NMDeviceWpanPrivate))

/*****************************************************************************/

/**
 * nm_device_wpan_get_hw_address:
 * @device: a #NMDeviceWpan
 *
 * Gets the active hardware (MAC) address of the #NMDeviceWpan
 *
 * Returns: the active hardware address. This is the internal string used by the
 * device, and must not be modified.
 **/
const char *
nm_device_wpan_get_hw_address (NMDeviceWpan *device)
{
        g_return_val_if_fail (NM_IS_DEVICE_WPAN (device), NULL);

        return nm_str_not_empty (NM_DEVICE_WPAN_GET_PRIVATE (device)->hw_address);
}

static gboolean
connection_compatible (NMDevice *device, NMConnection *connection, GError **error)
{
	if (!NM_DEVICE_CLASS (nm_device_wpan_parent_class)->connection_compatible (device, connection, error))
		return FALSE;

	if (!nm_connection_is_type (connection, NM_SETTING_WPAN_SETTING_NAME)) {
		g_set_error_literal (error, NM_DEVICE_ERROR, NM_DEVICE_ERROR_INCOMPATIBLE_CONNECTION,
		                     _("The connection was not a wpan connection."));
		return FALSE;
	}

	return TRUE;
}

static GType
get_setting_type (NMDevice *device)
{
	return NM_TYPE_SETTING_WPAN;
}

static const char *
get_hw_address (NMDevice *device)
{
	return nm_device_wpan_get_hw_address (NM_DEVICE_WPAN (device));
}

/*****************************************************************************/

static void
get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
{
	switch (prop_id) {
	case PROP_HW_ADDRESS:
		g_value_set_string (value, nm_device_wpan_get_hw_address (NM_DEVICE_WPAN (object)));
		break;
	default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
		break;
	}
}

static void
nm_device_wpan_init (NMDeviceWpan *device)
{
}

static void
init_dbus (NMObject *object)
{
        NMDeviceWpanPrivate *priv = NM_DEVICE_WPAN_GET_PRIVATE (object);
	const NMPropertiesInfo property_info[] = {
		{ NM_DEVICE_WPAN_HW_ADDRESS, &priv->hw_address },
		{ NULL },
	};

	NM_OBJECT_CLASS (nm_device_wpan_parent_class)->init_dbus (object);

	_nm_object_register_properties (object,
	                                NM_DBUS_INTERFACE_DEVICE_WPAN,
	                                property_info);
}

static void
finalize (GObject *object)
{
        NMDeviceWpanPrivate *priv = NM_DEVICE_WPAN_GET_PRIVATE (object);

        g_free (priv->hw_address);

        G_OBJECT_CLASS (nm_device_wpan_parent_class)->finalize (object);
}

static void
nm_device_wpan_class_init (NMDeviceWpanClass *wpan_class)
{
	GObjectClass *object_class = G_OBJECT_CLASS (wpan_class);
	NMObjectClass *nm_object_class = NM_OBJECT_CLASS (wpan_class);
	NMDeviceClass *device_class = NM_DEVICE_CLASS (wpan_class);

	g_type_class_add_private (wpan_class, sizeof (NMDeviceWpanPrivate));

	/* virtual methods */
	object_class->finalize = finalize;
	object_class->get_property = get_property;

	nm_object_class->init_dbus = init_dbus;

	device_class->connection_compatible = connection_compatible;
	device_class->get_setting_type = get_setting_type;
	device_class->get_hw_address = get_hw_address;

	/* properties */

	/**
	 * NMDeviceWpan:hw-address:
	 *
	 * The active hardware (MAC) address of the device.
	 **/
	g_object_class_install_property
		(object_class, PROP_HW_ADDRESS,
		 g_param_spec_string (NM_DEVICE_WPAN_HW_ADDRESS, "", "",
		                      NULL,
		                      G_PARAM_READABLE |
		                      G_PARAM_STATIC_STRINGS));
}

==> NetworkManager-1.25.1.tar.xz: NetworkManager-1.25.1/libnm/nm-device-wpan.c <==
// SPDX-License-Identifier: LGPL-2.1+
/*
 * Copyright (C) 2018 Lubomir Rintel <lkundrak@v3.sk>
 */

#include "nm-default.h"

#include "nm-device-wpan.h"

#include "nm-object-private.h"
#include "nm-setting-wpan.h"
#include "nm-setting-connection.h"

/*****************************************************************************/

struct _NMDeviceWpan {
	NMDevice parent;
};

struct _NMDeviceWpanClass {
	NMDeviceClass parent;
};

G_DEFINE_TYPE (NMDeviceWpan, nm_device_wpan, NM_TYPE_DEVICE)
/*****************************************************************************/

/**
 * nm_device_wpan_get_hw_address:
 * @device: a #NMDeviceWpan
 *
 * Gets the active hardware (MAC) address of the #NMDeviceWpan
 *
 * Returns: the active hardware address. This is the internal string used by the
 * device, and must not be modified.
 *
 * Deprecated: 1.24: Use nm_device_get_hw_address() instead.
 **/
const char *
nm_device_wpan_get_hw_address (NMDeviceWpan *device)
{
	g_return_val_if_fail (NM_IS_DEVICE_WPAN (device), NULL);

	return nm_device_get_hw_address (NM_DEVICE (device));
}

static gboolean
connection_compatible (NMDevice *device, NMConnection *connection, GError **error)
{
	if (!NM_DEVICE_CLASS (nm_device_wpan_parent_class)->connection_compatible (device, connection, error))
		return FALSE;

	if (!nm_connection_is_type (connection, NM_SETTING_WPAN_SETTING_NAME)) {
		g_set_error_literal (error, NM_DEVICE_ERROR, NM_DEVICE_ERROR_INCOMPATIBLE_CONNECTION,
		                     _("The connection was not a wpan connection."));
		return FALSE;
	}

	return TRUE;
}

static GType
get_setting_type (NMDevice *device)
{
	return NM_TYPE_SETTING_WPAN;
}

/*****************************************************************************/

static void
nm_device_wpan_init (NMDeviceWpan *device)
{
}

const NMLDBusMetaIface _nml_dbus_meta_iface_nm_device_wpan = NML_DBUS_META_IFACE_INIT (
	NM_DBUS_INTERFACE_DEVICE_WPAN,
	nm_device_wpan_get_type,
	NML_DBUS_META_INTERFACE_PRIO_INSTANTIATE_HIGH,
	NML_DBUS_META_IFACE_DBUS_PROPERTIES (
		NML_DBUS_META_PROPERTY_INIT_FCN ("HwAddress", 0, "s", _nm_device_notify_update_prop_hw_address ),
	),
);

static void
nm_device_wpan_class_init (NMDeviceWpanClass *wpan_class)
{
	NMDeviceClass *device_class = NM_DEVICE_CLASS (wpan_class);

	device_class->connection_compatible = connection_compatible;
	device_class->get_setting_type      = get_setting_type;
}
